#!/usr/bin/env python
# coding=utf-8

from setuptools import setup,find_packages
setup(name='sufartest',
     version='0.0.2',
     keywords=('bee','egg'),
     description='a simple egg',
     license='MIT License',
     url='http://liluo.org',
     author='Sufar',
     author_email='1160189043@qq.com',
     packages=find_packages(),
     include_package_data=True,
     platforms='any',
     install_requires =[])
